Automated Testing and Documentation
====================================

DMT-core uses an automated test and documentation-generation system based on a Docker Image and the Gitlab CI/CD.
The tests are run whenever the main or pre-main branch are updated.
This page explains the CI File and how the Docker image can be updated.

.. toctree::
    :maxdepth: 1

    automated_test
    updating_docker
    windows_installer
